GeneratorConnector
=====================================


.. autoclass:: sdgx.data_connectors.generator_connector.GeneratorConnector
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
    :private-members:
